@@ -3,6 +3,8 @@
 #' A function for shoreline dating Stone Age sites based on their present-day
 #'  elevation, their likely elevation above sea-level when in use and the
 #'  trajectory of past shoreline displacement on the Norwegian Skagerrak coast.
+#'  Details and caveats pertaining to the implemented method is given in
+#'  Roalkvam (2023).
 #'
 #' @param sites Vector giving one or more site names, or, if displacement curves
 #'   are to be interpolated, objects of class `sf` representing the sites to be
@@ -12,7 +14,7 @@
 #'  an elevation raster of class `SpatRaster` from the package
 #'  `terra` from where the elevation values are to be derived.
 #' @param elev_reso Numeric value specifying the resolution with which to step
-#'  through the gamma distribution representing the distance between site and
+#'  through the distribution representing the distance between site and
 #'  shoreline. Defaults to 0.01m.
 #' @param cal_reso Numeric value specifying the resolution to use on the
 #'   calendar scale. Defaults to 10.
@@ -21,9 +23,13 @@
 #' @param sum_isobase_directions Logical value indicating that if multiple
 #'  isobase directions are specified in `isobase_direction` the results should
 #'  be summed for each site using `sum_shoredates`. Defaults to FALSE.
-#' @param model_parameters Vector of two numeric values specifying the shape and
-#'   scale of the gamma distribution. Defaults to c(0.286, 20.833), denoting
-#'   the shape and scale, respectively.
+#' @param model Character vector specifying the statistical model with which to
+#'  model the distance from site to shoreline. Currently accepts either "none"
+#'  or "gamma". Defaults to "gamma".
+#' @param model_parameters Vector of numeric values specifying the parameters
+#'  for the statistical model describing the distance between site and
+#'  shoreline. Defaults to c(0.286, 20.833), denoting the shape and scale of the
+#'   default gamma function, respectively.
 #' @param elev_fun Statistic to define site elevation if this is to be derived
 #'  from an elevation raster. Uses `terra::extract()`. Defaults to mean.
 #' @param interpolated_curve List holding precomputed shoreline displacement
@@ -50,6 +56,7 @@
 #'  * `date` data frame with the columns `bce` where negative values
 #'  indicate years BCE and positive CE, as well as `probability`, which gives
 #'  the probability mass for each year.
+#'  * `weighted_mean` the weighted mean date.
 #'  * `hdr_start` start values for the HDR ranges.
 #'  * `hdr_end` end values for the HDR ranges.
 #'  * `hdr_prob` probability level for the HDR.
@@ -58,10 +65,8 @@
 #'  the lower limit for the elevation of the shoreline for each year.
 #'  `upperelev`, the upper limit for elevation of the shoreline for each year.
 #'  * `dispcurve_direction` direction of the isobases in use.
-#'  * `model_parameters` parameters for the gamma distribution. The
-#'  first value gives the shape and the second value the scale of the
-#'  distribution.
-#'  * `gammdat` data frame holding the gamma distribution. The column
+#'  * `model_parameters` parameters for the statistical model.
+#'  * `modeldat` data frame holding the model distribution. The column
 #'  `offset` denotes the vertical distance (m) from the shoreline, as specified
 #'  by the `elev_reso` argument. `px` is the cumulative probability at each step
 #'  of `offset`, and `probs` is the probability of each step found by
@@ -74,6 +79,12 @@
 #' @import terra
 #' @importFrom utils txtProgressBar
 #'
+#' @references
+#' Roalkvam, I. 2023. A simulation-based assessment of the relation between
+#'  Stone Age sites and relative sea-level change along the Norwegian Skagerrak
+#'  coast. \emph{Quaternary Science Reviews} 299:107880. DOI:
+#'  https://doi.org/10.1016/j.quascirev.2022.107880
+#'
 #' @examples
 #' # Create example point using the required CRS WGS84 UTM32N (EPSG: 32632)
 #' target_point <- sf::st_sfc(sf::st_point(c(538310, 6544255)), crs = 32632)
@@ -90,6 +101,7 @@ shoreline_date <- function(sites,
                            cal_reso = 10,
                            isobase_direction = 327,
                            sum_isobase_directions = FALSE,
+                           model = "gamma",
                            model_parameters = c(0.286, 20.833),
                            elev_fun = "mean",
                            interpolated_curve = NA,
@@ -102,7 +114,7 @@ shoreline_date <- function(sites,
   if(!inherits(sites, c("sf", "data.frame"))){
     if (is.na(interpolated_curve) & inherits(sites, "sfc")) {
       sites <- sf::st_as_sf(sites, crs = sf::st_crs(sites))
-    # Make vector of site names a data frame for nrow() below
+      # Make vector of site names a data frame for nrow() below
     } else {
       sites <- as.data.frame(sites)
     }
@@ -211,10 +223,10 @@ shoreline_date <- function(sites,
       # the default.
       if (is.na(msdate) & unique(temp_curve$direction) == 327) {
         warning(paste0("The elevation of site ", site_name,
-                      " implies an earliest possible date older than ", mdate,
-                      " BCE and is out of bounds. The date is returned as NA."))
+                       " implies an earliest possible date older than ", mdate,
+                       " BCE and is out of bounds. The date is returned as NA."))
         dategrid$probability <- NA
-        gammadat <- NA
+        modeldat <- NA
       } else if (is.na(msdate)) {
         warning(paste0("The elevation of site ", site_name,
                        " with an isobase direction of ",
@@ -222,29 +234,36 @@ shoreline_date <- function(sites,
                        " implies an earliest possible date older than ", mdate,
                        " BCE and is out of bounds. The date is returned as NA."))
         dategrid$probability <- NA
-        gammadat <- NA
+        modeldat <- NA
       } else {
 
-        # Set up data frame and assign probability to the offset increments
-        gammadat <- data.frame(
-          offset = inc,
-          px = stats::pgamma(inc, shape = model_parameters[1],
-                             scale =  model_parameters[2]))
-        gammadat$probs <- c(diff(gammadat$px), 0)
-        gammdat <- gammadat[gammadat$px < 0.99999,]
+        if(model == "gamma"){
+          # Set up data frame and assign probability to the offset increments
+          modeldat <- data.frame(
+            offset = inc,
+            px = stats::pgamma(inc, shape = model_parameters[1],
+                               scale =  model_parameters[2]))
+          modeldat$probs <- c(diff(modeldat$px), 0)
+          modeldat <- modeldat[modeldat$px < 0.99999,]
+        } else if(model == "none"){
+          modeldat <- data.frame(
+            offset = 0,
+            probs = 1
+          )
+        }
 
         if (verbose) {
           print("Performing shoreline dating")
           pb <- utils::txtProgressBar(min = 0,
-                                      max = nrow(gammadat),
+                                      max = nrow(modeldat),
                                       style = 3,
                                       char = "=")
         }
 
-        for (j in 1:nrow(gammadat)) {
+        for (j in 1:nrow(modeldat)) {
 
           # Subtract offset
-          adjusted_elev <- as.numeric(siteelev - gammadat$offset[j])
+          adjusted_elev <- as.numeric(siteelev - modeldat$offset[j])
 
           # Find lower date
           lowerd <- stats::approx(temp_curve[,"lowerelev"], bce,
@@ -267,7 +286,7 @@ shoreline_date <- function(sites,
             year_range <- seq(earliest, latest, cal_reso)
 
             # Identify probability to be distributed across range
-            prob <- 1/length(year_range) * gammadat$probs[j]
+            prob <- 1/length(year_range) * modeldat$probs[j]
 
             # Add probability to calendar years
             dategrid[dategrid$bce %in% year_range, "probability"] <-
@@ -318,6 +337,7 @@ shoreline_date <- function(sites,
           site_name = site_name,
           site_elev = siteelev,
           date = dategrid,
+          weighted_mean = hdr$weighted_mean,
           hdr_start = hdr$start,
           hdr_end = hdr$end,
           hdr_prob = hdr_prob,
@@ -325,7 +345,7 @@ shoreline_date <- function(sites,
                                    c("bce", "lowerelev", "upperelev")],
           dispcurve_direction = unique(temp_curve$direction),
           model_parameters = model_parameters,
-          gammadat = gammadat,
+          modeldat = modeldat,
           cal_reso = cal_reso)
 
       } else if (all(is.na(dategrid$probability)) & !sparse){
@@ -333,6 +353,7 @@ shoreline_date <- function(sites,
           site_name = site_name,
           site_elev = siteelev,
           date = dategrid,
+          weighted_mean = NA,
           hdr_start = NA,
           hdr_end = NA,
           hdr_prob = hdr_prob,
@@ -340,7 +361,7 @@ shoreline_date <- function(sites,
                                    c("bce", "lowerelev", "upperelev")],
           dispcurve_direction = unique(temp_curve$direction),
           model_parameters = model_parameters,
-          gammadat = gammadat,
+          modeldat = modeldat,
           cal_reso = cal_reso)
       } else {
         date_isobases[[k]] <- dategrid
@@ -358,14 +379,15 @@ shoreline_date <- function(sites,
         site_name = site_name,
         site_elev = siteelev,
         date = sum_isobases$sum,
+        weighted_mean = hdr$weighted_mean,
         hdr_start = hdr$start,
         hdr_end = hdr$end,
         hdr_prob = hdr_prob,
         dispcurve = NA,
         dispcurve_direction = unlist(lapply(date_isobases,
-                             function(x) unique(x["dispcurve_direction"]))),
+                                            function(x) unique(x["dispcurve_direction"]))),
         model_parameters = model_parameters,
-        gammadat = gammadat,
+        modeldat = modeldat,
         cal_reso = cal_reso
       ))
 
